#!/usr/bin/env python3
# Author: Baozhu Zuo <zuobaozhu@gmail.com>
# Copyright (c) 2018 Seeed Corporation.
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import time
import os
import dbus

from bluezero import constants
from bluezero import adapter
from bluezero import device


def list_devices():
    """Return list of adapters address available on system."""
    addresses = []
    bus = dbus.SystemBus()
    manager = dbus.Interface(
        bus.get_object(constants.BLUEZ_SERVICE_NAME, '/'),
        constants.DBUS_OM_IFACE)
    manager_obj = manager.GetManagedObjects()
    for path in manager_obj.keys():
        #if path[:-1] != '/org/bluez/hci' and path != '/org/bluez':
        #len(/org/bluez/hci0/dev_50_01_D9_BE_5E_7C) = 37
        if len(path) == 37:
            #convert path like /org/bluez/hci0/dev_50_01_D9_BE_5E_7C to 50:01:D9:BE:5E:7C
            addresses.append(path[len('/org/bluez/hci0/dev_'):].replace('_',':'))


    return addresses



def main():
    #wait for bluetooth ready
    while True:
        try:
            dongles = adapter.list_adapters()
            break
        except :
            time.sleep(1)
    dongle = adapter.Adapter(dongles[0])

    add_tailer =  dongle.address.replace(':','')[-4:]
    print('name: ', dongle.name)
    os.system('hcitool cmd 0x3F 0x01C 0x01 0x02 0x00 0x01 0x01')
    os.system("sed -i 's/#Name\ =\ BlueZ/Name\ =\ ReSpeaker-"+ add_tailer +"/g' /etc/bluetooth/main.conf")
    os.system('hciconfig hci0 name ReSpeaker-'+add_tailer)



    if not dongle.powered:
        dongle.powered = True
        print('Now powered: ', dongle.powered)

    while True:
        is_connected = False
        for devices_addr in list_devices():
            if devices_addr != None:
                d = device.Device(dongle.address,devices_addr)
                if d.connected == True:
                    is_connected = True
                    break
                if d.trusted == False:
                    d.trusted = True    
        time.sleep(1)
        
        try:
            if is_connected == False:
                dongle.discoverable = True
                continue
            else:
                dongle.discoverable = False
        except:
            time.sleep(1)
        # print('trusted: ', d.trusted)
        # print('connected: ', d.connected)
        # print('discoverable: ', dongle.discoverable)

        

if __name__ == '__main__':
    main()
